@@ -19,12 +19,12 @@ import os
 from keystoneclient.contrib.ec2 import utils as ec2_utils
 from lxml import etree
 from oslo_config import cfg
-import six.moves.urllib.parse as urlparse
+from oslo_log import log
+import urllib.parse as urlparse
 
 from os_collect_config import common
 from os_collect_config import exc
 from os_collect_config import merger
-from os_collect_config.openstack.common import log
 
 CONF = cfg.CONF
 logger = log.getLogger(__name__)
@@ -42,13 +42,17 @@ opts = [
     cfg.MultiStrOpt('path',
                     help='Path to Metadata'),
     cfg.StrOpt('secret-access-key',
+               secret=True,
                help='Secret Access Key'),
     cfg.StrOpt('access-key-id',
                help='Access Key ID'),
     cfg.MultiStrOpt('deployment-key',
                     default=['deployments'],
                     help='DEPRECATED, use global configuration option '
-                         '"deployment-key"')
+                         '"deployment-key"'),
+    cfg.FloatOpt('timeout', default=10,
+                 help='Seconds to wait for the connection and read request'
+                      ' timeout.')
 ]
 name = 'cfn'
 
@@ -107,7 +111,8 @@ class Collector(object):
             try:
                 content = self._session.get(
                     url, params=params, headers=headers,
-                    verify=CONF.cfn.ca_certificate)
+                    verify=CONF.cfn.ca_certificate,
+                    timeout=CONF.cfn.timeout)
                 content.raise_for_status()
             except self._requests_impl.exceptions.RequestException as e:
                 logger.warn(e)
