@@ -239,8 +239,11 @@ def getfilehash(files):
     return m.hexdigest()
 
 
-def __main__(args=sys.argv, collector_kwargs_map=None):
+def main(args=sys.argv, collector_kwargs_map=None):
     signal.signal(signal.SIGHUP, reexec_self)
+    # NOTE(bnemec): We need to exit on SIGPIPEs so systemd can restart us.
+    #               See lp 1795030
+    signal.signal(signal.SIGPIPE, signal.SIG_DFL)
     setup_conf()
     CONF(args=args[1:], prog="os-collect-config",
          version=version.version_info.version_string())
@@ -313,7 +316,3 @@ def __main__(args=sys.argv, collector_kwargs_map=None):
             print(json.dumps(content, indent=1))
             break
     return exitval
-
-
-if __name__ == '__main__':
-    sys.exit(__main__())
